@@ -1,12 +1,13 @@
 # This file is part of libkd.
 # Licensed under a 3-clause BSD style license - see LICENSE
+from __future__ import print_function
 from distutils.core import setup, Extension
 import numpy
 import os.path
 
 from numpy.distutils.misc_util import get_numpy_include_dirs
 numpy_inc = get_numpy_include_dirs()
-print 'Numpy inc:', numpy_inc
+print('Numpy inc:', numpy_inc)
 
 def strlist(s, split=' '):
     lst = s.split(split)
@@ -21,10 +22,10 @@ link = strlist(link)
 inc = strlist(os.environ.get('INC', ''), split='-I')
 cflags = strlist(os.environ.get('CFLAGS', ''))
 
-print 'link:', link
+print('link:', link)
 #print 'objs:', objs
-print 'inc:', inc
-print 'cflags:', cflags
+print('inc:', inc)
+print('cflags:', cflags)
 
 c_module = Extension('spherematch_c',
                      sources = ['pyspherematch.c'],
