@@ -1,5 +1,7 @@
 # This file is part of the Astrometry.net suite.
 # Licensed under a 3-clause BSD style license - see LICENSE
+from __future__ import print_function
+from __future__ import absolute_import
 import os
 from astrometry.util.fits import fits_table
 import numpy as np
@@ -19,9 +21,9 @@ except:
         except ImportError:
             raise ImportError("Cannot import either pyfits or astropy.io.fits")
 
-from common import *
-from dr7 import *
-from yanny import *
+from .common import *
+from .dr7 import *
+from .yanny import *
 from astrometry.util.run_command import run_command
 
 class Frame(SdssFile):
@@ -316,10 +318,10 @@ class DR8(DR7):
             tempfn = os.path.join(udir, os.path.basename(fn).replace('.bz2', ''))
             #print 'Checking', tempfn
             if os.path.exists(tempfn):
-                print 'File exists:', tempfn
+                print('File exists:', tempfn)
                 return tempfn,True
             else:
-                print 'Saving to', tempfn
+                print('Saving to', tempfn)
                 keep = True
 
         else:
@@ -328,17 +330,17 @@ class DR8(DR7):
 
         cmd = cmd % dict(input = fn, output = tempfn)
         self.logger.debug('cmd: %s' % cmd)
-        print 'command:', cmd
+        print('command:', cmd)
         (rtn,out,err) = run_command(cmd)
         if rtn:
-            print 'Command failed: command', cmd
-            print 'Output:', out
-            print 'Error:', err
-            print 'Return val:', rtn
+            print('Command failed: command', cmd)
+            print('Output:', out)
+            print('Error:', err)
+            print('Return val:', rtn)
             raise RuntimeError('Command failed (return val %i): %s' % (rtn, cmd))
 
-        print out
-        print err
+        print(out)
+        print(err)
         return tempfn,keep
 
 
@@ -375,10 +377,11 @@ class DR8(DR7):
 
         outfn = self.getPath(filetype, run, camcol, field, band,
                              rerun=rerun)
-        print 'Checking for file', outfn
+        print('Checking for file', outfn)
         if outfn is None:
             return None
         if skipExisting and os.path.exists(outfn):
+            #print('Exists')
             return outfn
         outdir = os.path.dirname(outfn)
         if not os.path.exists(outdir):
@@ -388,7 +391,7 @@ class DR8(DR7):
                 pass
         url = self.get_url(filetype, run, camcol, field, band=band, rerun=rerun)
         #print 'Did not find file:', outfn
-        print 'Retrieving from URL:', url
+        print('Retrieving from URL:', url)
         if self.curl:
             cmd = "curl -o '%(outfn)s' '%(url)s'"
         else:
@@ -405,10 +408,10 @@ class DR8(DR7):
         self.logger.debug('cmd: %s' % cmd)
         (rtn,out,err) = run_command(cmd)
         if rtn:
-            print 'Command failed: command', cmd
-            print 'Output:', out
-            print 'Error:', err
-            print 'Return val:', rtn
+            print('Command failed: command', cmd)
+            print('Output:', out)
+            print('Error:', err)
+            print('Return val:', rtn)
             return None
 
         if tempsuffix is not None:
@@ -422,10 +425,10 @@ class DR8(DR7):
             self.logger.debug('cmd: %s' % cmd)
             (rtn,out,err) = run_command(cmd)
             if rtn:
-                print 'Command failed: command', cmd
-                print 'Output:', out
-                print 'Error:', err
-                print 'Return val:', rtn
+                print('Command failed: command', cmd)
+                print('Output:', out)
+                print('Error:', err)
+                print('Return val:', rtn)
                 return None
 
         return outfn
@@ -457,7 +460,7 @@ class DR8(DR7):
 
         if fitsio:
 
-            print 'Frame filename', fn
+            print('Frame filename', fn)
             # eg /clusterfs/riemann/raid006/dr10/boss/photoObj/frames/301/2825/1/frame-u-002825-1-0126.fits.bz2
 
             F = fitsio.FITS(fn, lower=True)
