@@ -454,7 +454,9 @@ class tabledata(object):
                 raise
                 
     def write_to(self, fn, columns=None, header='default', primheader=None,
-                 use_fitsio=True, append=False, append_to_hdu=None):
+                 use_fitsio=True, append=False, append_to_hdu=None,
+                 fits_object=None,
+                 **kwargs):
 
         fitsio = None
         if use_fitsio:
@@ -468,7 +470,10 @@ class tabledata(object):
 
         if fitsio:
             arrays = [self.get(c) for c in columns]
-            fits = fitsio.FITS(fn, 'rw', clobber=(not append))
+            if fits_object is not None:
+                fits = fits_object
+            else:
+                fits = fitsio.FITS(fn, 'rw', clobber=(not append))
 
             arrays = [np.array(a) if isinstance(a,list) else a
                       for a in arrays]
@@ -477,12 +482,15 @@ class tabledata(object):
                 header = None
             try:
                 if append and append_to_hdu is not None:
-                    fits[append_to_hdu].append(arrays, names=columns, header=header)
+                    fits[append_to_hdu].append(arrays, names=columns, header=header, **kwargs)
                 else:
                     if primheader is not None:
                         fits.write(None, header=primheader)
-                    fits.write(arrays, names=columns, header=header)
-                fits.close()
+                    fits.write(arrays, names=columns, header=header, **kwargs)
+
+                # If we were passed in a fits object, don't close it.
+                if fits_object is None:
+                    fits.close()
             except:
                 print('Failed to write FITS table')
                 print('Columns:')
@@ -496,7 +504,6 @@ class tabledata(object):
                 raise
             return
 
-
         fc = self.to_fits_columns(columns)
         T = pyfits.new_table(fc)
         if header == 'default':
@@ -683,8 +690,8 @@ def fits_table(dataorfn=None, rows=None, hdunum=1, hdu=None, ext=None,
                     from astropy.io import fits as pyfits
                     isrecarray = (type(data) == pyfits.fitsrec.FITS_rec)
                 except:
-                    import traceback
-                    traceback.print_exc()
+                    #import traceback
+                    #traceback.print_exc()
                     pass
         #if not isrecarray:
         #    if type(data) == np.recarray:
